% Definicion funciones A(y), T(y), R(y)
switch(canal.tipo)
  case 1 %RECTANGULAR

    function A=crossArea(y,canal) %area(y)
      %A=crossArea(y,canal) also as canal.area(y)
      A=canal.param(1)*y;
    endfunction

    function T=surfaceWidth(y,canal)  %anchosl(y)
    %T = surfaceWidth(y,canal) also as canal.anchosl(y)
      T=canal.param(1);
    endfunction

    % Shortway to use within the structure of a particular channel
    canal.area = @(y) crossArea(y,canal);
    canal.anchosl = @(y) surfaceWidth(y,canal);

    function R=hydraulicRadius(y,canal) %Rh(y)
      % R=hydraulicRadius(y,canal) also as canal.Rh(y)
      R=  canal.param(1)*y./(canal.param(1)+2*y);
    endfunction
    
    canal.Rh = @(y) hydraulicRadius(y,canal);

  case 2 % TRAPEZOIDAL
    function A=crossArea(y,canal)
      %A=crossArea(y,canal) also as canal.area(y)
      A=(canal.param(1)+canal.param(2)*y).*y;
    endfunction

    function T=surfaceWidth(y,canal)
    %T = surfaceWidth(y,canal) also as canal.anchosl(y)
      T=canal.param(1)+2*canal.param(2)*y;
    endfunction

    canal.area = @(y) crossArea(y,canal);
    canal.anchosl = @(y) surfaceWidth(y,canal);

    function R=hydraulicRadius(y,canal)
      % R=hydraulicRadius(y,canal) also as canal.Rh(y)
      R=(canal.param(1)+canal.param(2)*y).*y ./ (canal.param(1)+2*sqrt(1+canal.param(2)^2)*y);
    endfunction

    canal.Rh = @(y) hydraulicRadius(y,canal);



  case 5 %PARABOLICA
    % function A=crossArea(y,canal)
    % %A=crossArea(y,canal) also as canal.area(y)
    %   A=(2/3*y).^2
    % endfunction
    
    % function T=surfaceWidth(y,canal)
    % %T = surfaceWidth(y,canal) also as canal.anchosl(y)
    % T = 2/3*y;  
    % endfunction
    
    % function R=hydraulicRadius(y,canal)
    % % R=hydraulicRadius(y,canal) also as canal.Rh(y)
    %   T=2/3*y;
    %   R=2*T.^2.*y./(3*T.^2+8*y.^2);
    %   NO USAR AUN METER EXPRESION EXACTA!!!
    % endfunction
    % canal.area = @(y) crossArea(y,canal);
    % canal.anchosl = @(y) surfaceWidth(y,canal);
    % canal.Rh = @(y) hydraulicRadius(y,canal);
    
  case 6 %CIRCULAR
    function A=crossArea(y,canal)
     %A=crossArea(y,canal) also as canal.area(y)
      R=  canal.param(1)*y./(canal.param(1)+2*y);
      tita= acos(1-2*y/canal.param(1));
      A=0.25*(tita-0.5*sin(2*tita))*canal.param(1)^2;
    endfunction
    function T=surfaceWidth(y,canal)
    %T = surfaceWidth(y,canal) also as canal.anchosl(y)
      T=2*sqrt(y.*(canal.param(1)-y));
    endfunction
    function R=hydraulicRadius(y,canal)
      % R=hydraulicRadius(y,canal) also as canal.Rh(y)
      tita= acos(1-2*y/canal.param(1));
      R= area(y)./ (tita*canal.param(1));
    endfunction


  case 7 %HERRADURA A MEDIO ESCRIBIR FALTA Rh
    function A=crossArea(y,canal)
     %A=crossArea(y,canal) also as canal.area(y)
      yoverD = y/canal.param(1);
      if yoverD <= 0.0886,
        tita0 = acos(1-yoverD);
        A = (tita0 - 0.5* sin(tita0*2))*canal.param(1)^2;
      elseif  yoverD <= 0.5
        tita1 = asin(0.5-yoverD);
        A=(0.43662 - tita1+sin(tita1)*(1-cos(tita1)))*canal.param(1)^2;
      else
        tita2 = acos(2*yoverD-1)
        A = (0.82932 - tita2/4 + 0.5* sin(tita2*2))*canal.param(1)^2;
      endif
    endfunction
    function T=surfaceWidth(y,canal)
    %T = surfaceWidth(y,canal) also as canal.anchosl(y)
      yoverD = y/canal.param(1);
      if yoverD <= 0.0886,
        T= 2*sqrt(y.*(2*canal.param(1)-y));
      elseif  yoverD <= 0.5
        T= (2*sqrt(0.75+yoverD.*(1-yoverD))-1)*canal.param(1);
      else
        T= (2*sqrt(yoverD.*(1-yoverD)))*canal.param(1);
      endif
    endfunction

    function R=hydraulicRadius(y,canal)
      % R=hydraulicRadius(y,canal) also as canal.Rh(y)
      yoverD = y/canal.param(1);
      if yoverD <= 0.0886,
        tita0 = acos(1-yoverD);
        R=0.5*(1 - sin(2*tita0)/2/tita0)*canal.param(1);
      elseif  yoverD <= 0.5
        tita1 = asin(0.5-yoverD);
        R=((0.43662-tita1+sin(tita1)*(1-cos(tita1)))/(1.69623-2*tita1) )*canal.param(1);        
      else
        tita2 = acos(2*yoverD-1)
        R=((0.82932-0.25*tita2+0.5*sin(2*tita2))/(3.26703-tita2))*canal.param(1);
      endif     
    endfunction
    display('seccion no revisada / channel section not checked before');

    canal.area = @(y) crossArea(y,canal);
    canal.anchosl = @(y) surfaceWidth(y,canal);
    canal.Rh = @(y) hydraulicRadius(y,canal);







  case 20 %plantilla
    function A=crossArea(y,canal)
      global canal;

    endfunction
    function T=surfaceWidth(y,canal)
      global canal;

    endfunction
    function R=hydraulicRadius(y,canal)
      global canal;
      
    endfunction
    canal.area = @(y) crossArea(y,canal);
    canal.anchosl = @(y) surfaceWidth(y,canal);
    canal.Rh = @(y) hydraulicRadius(y,canal);


  
endswitch


%% Fr y Ie

function Frcuadrado = Fr2(y,Q,canal) %Fr2(y,Q)
  g=9.81;
  Frcuadrado = canal.alfa*Q.^2.*canal.anchosl(y)./(g*canal.area(y).^3*canal.costitas);
endfunction

function valueIe = Ie(y,Q,canal)
%  global canal;
  valueIe = canal.n^2*Q.^2 ./(canal.area(y).^2.*canal.Rh(y).^(4/3));
endfunction
